@@ -1,6 +1,7 @@
-from typing import List, Dict
+from typing import List, Dict, Optional
 
 from pyspark.sql import DataFrame, Column
+from pyspark.sql.types import StructField
 
 from spark_auto_mapper.automappers.automapper_base import AutoMapperBase
 from spark_auto_mapper.automappers.with_column_base import AutoMapperWithColumnBase
@@ -15,11 +16,23 @@ class AutoMapperContainer(AutoMapperBase):
         self.mappers: Dict[str, AutoMapperBase] = {}
 
     def generate_mappers(
-        self, mappers_dict: Dict[str, AutoMapperAnyDataType]
+        self, mappers_dict: Dict[str, AutoMapperAnyDataType],
+        column_schema: Dict[str, StructField], include_null_properties: bool,
+        skip_schema_validation: List[str],
+        skip_if_columns_null_or_empty: Optional[List[str]]
     ) -> None:
+        column: str
+        value: AutoMapperAnyDataType
         for column, value in mappers_dict.items():
+            # add an automapper
             automapper = AutoMapperWithColumnBase(
-                dst_column=column, value=value
+                dst_column=column,
+                value=value,
+                column_schema=column_schema[column] if column in column_schema
+                and column not in skip_schema_validation else None,
+                include_null_properties=include_null_properties
+                and column not in skip_schema_validation,
+                skip_if_columns_null_or_empty=skip_if_columns_null_or_empty
             )
             assert isinstance(automapper,
                               AutoMapperWithColumnBase), type(automapper)
