@@ -1,4 +1,4 @@
-from typing import List, Union, TypeVar
+from typing import List, Union, TypeVar, Optional
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import coalesce
@@ -28,8 +28,20 @@ class AutoMapperCoalesceDataType(AutoMapperTextLikeBase):
             AutoMapperValueParser.parse_value(value) for value in args
         ]
 
-    def get_column_spec(self, source_df: DataFrame) -> Column:
+    def get_column_spec(
+        self, source_df: DataFrame, current_column: Optional[Column]
+    ) -> Column:
         column_spec = coalesce(
-            *[col.get_column_spec(source_df=source_df) for col in self.value]
+            *[
+                col.get_column_spec(
+                    source_df=source_df, current_column=current_column
+                ) for col in self.value
+            ]
         )
         return column_spec
+
+    def include_null_properties(self, include_null_properties: bool) -> None:
+        for item in self.value:
+            item.include_null_properties(
+                include_null_properties=include_null_properties
+            )
