@@ -1,7 +1,8 @@
-from typing import Dict, Any
+from typing import Dict, Any, Optional
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import struct
+from pyspark.sql.types import StructType
 
 from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
 from spark_auto_mapper.helpers.value_parser import AutoMapperValueParser
@@ -29,15 +30,25 @@ class AutoMapperDataTypeComplexBase(AutoMapperDataTypeBase):
             for parameter_name, parameter_value in kwargs.items()
         }
 
-    def set_include_nulls(self, include_nulls: bool) -> None:
-        self.include_nulls = include_nulls
+    def include_null_properties(self, include_null_properties: bool) -> None:
+        self.include_nulls = include_null_properties
+        # now recursively set this into any other complex children
+        for key, value in self.get_child_mappers().items():
+            value.include_null_properties(
+                include_null_properties=include_null_properties
+            )
 
-    def get_column_spec(self, source_df: DataFrame) -> Column:
+    def get_column_spec(
+        self, source_df: DataFrame, current_column: Optional[Column]
+    ) -> Column:
         valid_columns = self.get_child_mappers()
         column_spec: Column = struct(
             [
-                self.get_value(value=value, source_df=source_df).alias(key)
-                for key, value in valid_columns.items()
+                self.get_value(
+                    value=value,
+                    source_df=source_df,
+                    current_column=current_column
+                ).alias(key) for key, value in valid_columns.items()
             ]
         )
         return column_spec
@@ -53,3 +64,8 @@ class AutoMapperDataTypeComplexBase(AutoMapperDataTypeBase):
             )
         }
         return valid_columns
+
+    # override this if your inherited class has a defined schema
+    # noinspection PyMethodMayBeStatic
+    def get_schema(self, include_extension: bool) -> Optional[StructType]:
+        return None
