@@ -5,6 +5,7 @@ from pyspark.sql.functions import array
 from pyspark.sql.functions import lit
 
 from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
+from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
 from spark_auto_mapper.helpers.spark_higher_order_functions import filter
 from spark_auto_mapper.helpers.value_parser import AutoMapperValueParser
 from spark_auto_mapper.type_definitions.native_types import AutoMapperNativeSimpleType
@@ -23,9 +24,11 @@ class AutoMapperList(AutoMapperDataTypeBase, Generic[_T]):
     """
     def __init__(
         self,
-        value: Optional[List[_T]],
+        value: Optional[Union[List[_T], AutoMapperDataTypeBase,
+                              List[AutoMapperDataTypeBase],
+                              List[AutoMapperTextLikeBase]]],
         remove_nulls: bool = True,
-        include_null_properties: bool = False
+        include_null_properties: bool = True
     ) -> None:
         """
         Generates a list (array) in Spark
@@ -44,21 +47,29 @@ class AutoMapperList(AutoMapperDataTypeBase, Generic[_T]):
         elif isinstance(value, AutoMapperDataTypeBase):
             self.value = value
         elif isinstance(value, List):
-            if include_null_properties and len(
-                value
-            ) > 1:  # if there are multiple items and the structs don't match then Spark errors
-                self.value = [
-                    AutoMapperValueParser.parse_value(v, include_nulls=True)
-                    for v in value
-                ]
-            else:
-                self.value = [
-                    AutoMapperValueParser.parse_value(v) for v in value
-                ]
+            self.value = [AutoMapperValueParser.parse_value(v) for v in value]
+            # if there are more than two items we have to maintain the same schema in children or Spark errors
+            if include_null_properties:
+                self.include_null_properties(
+                    include_null_properties=include_null_properties
+                )
         else:
             raise ValueError(f"{type(value)} is not supported")
 
-    def get_column_spec(self, source_df: DataFrame) -> Column:
+    def include_null_properties(self, include_null_properties: bool) -> None:
+        if isinstance(self.value, list):
+            for item in self.value:
+                item.include_null_properties(
+                    include_null_properties=include_null_properties
+                )
+        elif isinstance(self.value, AutoMapperDataTypeBase):
+            self.value.include_null_properties(
+                include_null_properties=include_null_properties
+            )
+
+    def get_column_spec(
+        self, source_df: DataFrame, current_column: Optional[Column]
+    ) -> Column:
         if isinstance(
             self.value, str
         ):  # if the src column is just string then consider it a sql expression
@@ -69,14 +80,14 @@ class AutoMapperList(AutoMapperDataTypeBase, Generic[_T]):
         ):  # if the src column is a list then iterate
             return filter(array(
                 [
-                    self.get_value(item, source_df=source_df)
+                    self.get_value(item, source_df=source_df, current_column=current_column)
                     for item in self.value
                 ]
             ), lambda x: x.isNotNull()) \
                 if self.remove_nulls \
                 else array(
                 [
-                    self.get_value(item, source_df=source_df)
+                    self.get_value(item, source_df=source_df, current_column=current_column)
                     for item in self.value
                 ]
             )
@@ -84,8 +95,8 @@ class AutoMapperList(AutoMapperDataTypeBase, Generic[_T]):
         # if value is an AutoMapper then ask it for its column spec
         if isinstance(self.value, AutoMapperDataTypeBase):
             child: AutoMapperDataTypeBase = self.value
-            return filter(array(child.get_column_spec(source_df=source_df)), lambda x: x.isNotNull()) \
-                if self.remove_nulls \
-                else array(child.get_column_spec(source_df=source_df))
+            return child.get_column_spec(
+                source_df=source_df, current_column=current_column
+            )
 
         raise ValueError(f"value: {self.value} is neither str nor AutoMapper")
