@@ -1,10 +1,10 @@
-from typing import Union
+from typing import Optional
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import substring_index
 
-from spark_auto_mapper.data_types.column import AutoMapperDataTypeColumn
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
+from spark_auto_mapper.type_definitions.wrapper_types import AutoMapperColumnOrColumnLikeType
 
 
 class AutoMapperSubstringByDelimiterDataType(AutoMapperTextLikeBase):
@@ -15,19 +15,21 @@ class AutoMapperSubstringByDelimiterDataType(AutoMapperTextLikeBase):
     substring_index performs a case-sensitive match when searching for delimiter.
     """
     def __init__(
-        self, column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
-        delimiter: str, delimiter_count: int
+        self, column: AutoMapperColumnOrColumnLikeType, delimiter: str,
+        delimiter_count: int
     ):
         super().__init__()
 
-        self.column: Union[AutoMapperDataTypeColumn,
-                           AutoMapperTextLikeBase] = column
+        self.column: AutoMapperColumnOrColumnLikeType = column
         self.delimiter: str = delimiter
         self.delimiter_count: int = delimiter_count
 
-    def get_column_spec(self, source_df: DataFrame) -> Column:
+    def get_column_spec(
+        self, source_df: DataFrame, current_column: Optional[Column]
+    ) -> Column:
         column_spec = substring_index(
-            self.column.get_column_spec(source_df=source_df), self.delimiter,
-            self.delimiter_count
+            self.column.get_column_spec(
+                source_df=source_df, current_column=current_column
+            ), self.delimiter, self.delimiter_count
         )
         return column_spec
