@@ -1,8 +1,16 @@
-from typing import Any, Dict, Union, TypeVar, cast, Optional
+from typing import Any, Dict, Union, TypeVar, cast, Optional, List, Callable
 
+from pyspark.sql.types import StringType
+
+from spark_auto_mapper.data_types.array_base import AutoMapperArrayLikeBase
 from spark_auto_mapper.data_types.coalesce import AutoMapperCoalesceDataType
+from spark_auto_mapper.data_types.field import AutoMapperDataTypeField
+from spark_auto_mapper.data_types.filter import AutoMapperFilterDataType
 from spark_auto_mapper.data_types.hash import AutoMapperHashDataType
+from spark_auto_mapper.data_types.if_ import AutoMapperIfDataType
 from spark_auto_mapper.data_types.if_not_null_or_empty import AutoMapperIfNotNullOrEmptyDataType
+from spark_auto_mapper.data_types.if_regex import AutoMapperIfRegExDataType
+from spark_auto_mapper.data_types.split_by_delimiter import AutoMapperSplitByDelimiterDataType
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
 
 from spark_auto_mapper.data_types.amount import AutoMapperAmountDataType
@@ -21,11 +29,12 @@ from spark_auto_mapper.data_types.complex.struct_type import AutoMapperDataTypeS
 from spark_auto_mapper.data_types.regex_replace import AutoMapperRegExReplaceDataType
 from spark_auto_mapper.data_types.substring import AutoMapperSubstringDataType
 from spark_auto_mapper.data_types.substring_by_delimiter import AutoMapperSubstringByDelimiterDataType
+from spark_auto_mapper.data_types.transform import AutoMapperTransformDataType
 from spark_auto_mapper.data_types.trim import AutoMapperTrimDataType
 from spark_auto_mapper.type_definitions.defined_types import AutoMapperAnyDataType, AutoMapperBooleanInputType, \
-    AutoMapperAmountInputType, AutoMapperNumberInputType, AutoMapperDateInputType
+    AutoMapperAmountInputType, AutoMapperNumberInputType, AutoMapperDateInputType, AutoMapperTextInputType
 from spark_auto_mapper.type_definitions.native_types import AutoMapperNativeTextType, AutoMapperNativeSimpleType
-from spark_auto_mapper.type_definitions.wrapper_types import AutoMapperWrapperType
+from spark_auto_mapper.type_definitions.wrapper_types import AutoMapperWrapperType, AutoMapperColumnOrColumnLikeType
 
 _TAutoMapperDataType = TypeVar(
     "_TAutoMapperDataType",
@@ -53,7 +62,7 @@ class AutoMapperHelpers:
         return AutoMapperDataTypeComplex(**kwargs)
 
     @staticmethod
-    def column(value: str) -> AutoMapperDataTypeColumn:
+    def column(value: str) -> AutoMapperArrayLikeBase:
         """
         Specifies that the value parameter should be used as a column name
         :param value: name of column
@@ -62,16 +71,18 @@ class AutoMapperHelpers:
         return AutoMapperDataTypeColumn(value)
 
     @staticmethod
-    def text(value: str) -> AutoMapperDataTypeLiteral:
+    def text(
+        value: Union[AutoMapperNativeSimpleType, AutoMapperTextInputType]
+    ) -> AutoMapperTextLikeBase:
         """
         Specifies that the value parameter should be used as a literal text
-        :param value: literal text value
-        :return: a literal automapper type
+        :param value: text value
+        :return: a text automapper type
         """
-        return AutoMapperDataTypeLiteral(value)
+        return AutoMapperDataTypeLiteral(value, StringType())
 
     @staticmethod
-    def expression(value: str) -> AutoMapperDataTypeExpression:
+    def expression(value: str) -> AutoMapperArrayLikeBase:
         """
         Specifies that the value parameter should be executed as a sql expression in Spark
         :param value: sql
@@ -134,14 +145,39 @@ class AutoMapperHelpers:
         return AutoMapperConcatDataType(*args)
 
     @staticmethod
-    def if_not_null(
-        check: AutoMapperDataTypeColumn,
+    def if_(
+        column: AutoMapperColumnOrColumnLikeType,
+        check: Union[AutoMapperAnyDataType, List[AutoMapperAnyDataType]],
         value: _TAutoMapperDataType,
-        when_null: Optional[Union[AutoMapperTextLikeBase,
-                                  _TAutoMapperDataType]] = None
+        else_: Optional[_TAutoMapperDataType] = None
     ) -> _TAutoMapperDataType:
         """
-        concatenates a list of values.  Each value can be a string or a column
+        Checks if column matches check_value.  Returns value if it matches else else_
+
+
+        :param column: column to check
+        :param check: value to compare the column to
+        :param value: what to return if the value matches
+        :param else_: what value to assign if check fails
+        :return: an if automapper type
+        """
+
+        # cast it to the inner type so type checking is happy
+        return cast(
+            _TAutoMapperDataType,
+            AutoMapperIfDataType(
+                column=column, check=check, value=value, else_=else_
+            )
+        )
+
+    @staticmethod
+    def if_not_null(
+        check: AutoMapperColumnOrColumnLikeType,
+        value: _TAutoMapperDataType,
+        when_null: Optional[_TAutoMapperDataType] = None
+    ) -> _TAutoMapperDataType:
+        """
+        Checks if `check` is null
 
 
         :param check: column to check for null
@@ -160,13 +196,12 @@ class AutoMapperHelpers:
 
     @staticmethod
     def if_not_null_or_empty(
-        check: AutoMapperDataTypeColumn,
+        check: AutoMapperColumnOrColumnLikeType,
         value: _TAutoMapperDataType,
-        when_null_or_empty: Optional[Union[AutoMapperTextLikeBase,
-                                           _TAutoMapperDataType]] = None
+        when_null_or_empty: Optional[_TAutoMapperDataType] = None
     ) -> _TAutoMapperDataType:
         """
-        concatenates a list of values.  Each value can be a string or a column
+        Checks if `check` is null or empty.
 
 
         :param check: column to check for null
@@ -187,9 +222,9 @@ class AutoMapperHelpers:
 
     @staticmethod
     def map(
-        column: AutoMapperDataTypeColumn,
-        mapping: Dict[str, AutoMapperNativeSimpleType],
-        default: Optional[AutoMapperNativeSimpleType] = None
+        column: AutoMapperColumnOrColumnLikeType,
+        mapping: Dict[AutoMapperTextInputType, AutoMapperAnyDataType],
+        default: Optional[AutoMapperAnyDataType] = None
     ) -> AutoMapperDataTypeExpression:
         """
         maps the contents of a column to values
@@ -205,8 +240,7 @@ class AutoMapperHelpers:
 
     @staticmethod
     def left(
-        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
-        length: int
+        column: AutoMapperColumnOrColumnLikeType, length: int
     ) -> AutoMapperSubstringDataType:
         """
         Take the specified number of first characters in a string
@@ -221,8 +255,7 @@ class AutoMapperHelpers:
 
     @staticmethod
     def right(
-        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
-        length: int
+        column: AutoMapperColumnOrColumnLikeType, length: int
     ) -> AutoMapperSubstringDataType:
         """
         Take the specified number of last characters in a string
@@ -237,8 +270,7 @@ class AutoMapperHelpers:
 
     @staticmethod
     def substring(
-        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
-        start: int, length: int
+        column: AutoMapperColumnOrColumnLikeType, start: int, length: int
     ) -> AutoMapperSubstringDataType:
         """
         Finds a substring in the specified string.
@@ -254,8 +286,7 @@ class AutoMapperHelpers:
 
     @staticmethod
     def string_before_delimiter(
-        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
-        delimiter: str
+        column: AutoMapperColumnOrColumnLikeType, delimiter: str
     ) -> AutoMapperSubstringByDelimiterDataType:
         """
         Take the specified number of first characters in a string
@@ -270,8 +301,7 @@ class AutoMapperHelpers:
 
     @staticmethod
     def string_after_delimiter(
-        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
-        delimiter: str
+        column: AutoMapperColumnOrColumnLikeType, delimiter: str
     ) -> AutoMapperSubstringByDelimiterDataType:
         """
         Take the specified number of first characters in a string
@@ -286,15 +316,15 @@ class AutoMapperHelpers:
 
     @staticmethod
     def substring_by_delimiter(
-        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
-        delimiter: str, delimiter_count: int
+        column: AutoMapperColumnOrColumnLikeType, delimiter: str,
+        delimiter_count: int
     ) -> AutoMapperSubstringByDelimiterDataType:
         """
         Returns the substring from string str before count occurrences of the delimiter.
         substring_by_delimiter performs a case-sensitive match when searching for delimiter.
 
         :param column: column whose contents to use
-        :param delimiter: string to use as delimiter
+        :param delimiter: string to use as delimiter.  can be a regex.
         :param delimiter_count: If delimiter_count is positive, everything the left of the final delimiter
                                     (counting from left) is returned.
                                 If delimiter_count is negative, every to the right of the final delimiter
@@ -309,8 +339,8 @@ class AutoMapperHelpers:
 
     @staticmethod
     def regex_replace(
-        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
-        pattern: str, replacement: str
+        column: AutoMapperColumnOrColumnLikeType, pattern: str,
+        replacement: str
     ) -> AutoMapperRegExReplaceDataType:
         """
         Replace all substrings of the specified string value that match regexp with rep.
@@ -326,7 +356,7 @@ class AutoMapperHelpers:
 
     @staticmethod
     def trim(
-        column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase]
+        column: AutoMapperColumnOrColumnLikeType
     ) -> AutoMapperTrimDataType:
         """
         Trim the spaces from both ends for the specified string column.
@@ -343,18 +373,116 @@ class AutoMapperHelpers:
     ) -> AutoMapperHashDataType:
         """
         Calculates the hash code of given columns, and returns the result as an int column.
+
+
         :param args: string or column
         :return: a concat automapper type
         """
         return AutoMapperHashDataType(*args)
 
     @staticmethod
-    def coalesce(*args: _TAutoMapperDataType, ) -> _TAutoMapperDataType:
+    def coalesce(*args: _TAutoMapperDataType) -> _TAutoMapperDataType:
         """
-        Returns the first column that is not null.
+        Returns the first value that is not null.
 
         :return: a coalesce automapper type
         """
 
         # cast it to the inner type so type checking is happy
         return cast(_TAutoMapperDataType, AutoMapperCoalesceDataType(*args))
+
+    @staticmethod
+    def if_regex(
+        column: AutoMapperColumnOrColumnLikeType,
+        check: Union[str, List[str]],
+        value: _TAutoMapperDataType,
+        else_: Optional[_TAutoMapperDataType] = None
+    ) -> _TAutoMapperDataType:
+        """
+        Checks if column matches check_value.  Returns value if it matches else else_
+
+
+        :param column: column to check
+        :param check: value to compare the column to. Has to be a string or list of strings
+        :param value: what to return if the value matches
+        :param else_: what value to assign if check fails
+        :return: an if automapper type
+        """
+
+        # cast it to the inner type so type checking is happy
+        return cast(
+            _TAutoMapperDataType,
+            AutoMapperIfRegExDataType(
+                column=column, check=check, value=value, else_=else_
+            )
+        )
+
+    @staticmethod
+    def filter(
+        column: AutoMapperColumnOrColumnLikeType,
+        func: Callable[[Dict[str, Any]], Any]
+    ) -> AutoMapperFilterDataType:
+        """
+        Filters a column by a function
+
+
+        :param column: column to check
+        :param func: func to filter by
+        :return: a filter automapper type
+        """
+        # # cast it to the inner type so type checking is happy
+        # return cast(
+        #     _TAutoMapperDataType,
+        #     AutoMapperFilterDataType(column=column, func=func)
+        # )
+        return AutoMapperFilterDataType(column=column, func=func)
+
+    @staticmethod
+    def transform(
+        column: AutoMapperColumnOrColumnLikeType, value: _TAutoMapperDataType
+    ) -> List[_TAutoMapperDataType]:
+        """
+        transforms a column into another type or struct
+
+
+        :param column: column to check
+        :param value: func to create type or struct
+        :return: a transform automapper type
+        """
+        # cast it to the inner type so type checking is happy
+        return cast(
+            List[_TAutoMapperDataType],
+            AutoMapperTransformDataType(column=column, value=value)
+        )
+
+    @staticmethod
+    def field(value: str) -> AutoMapperTextLikeBase:
+        """
+        Specifies that the value parameter should be used as a field name
+        :param value: name of column
+        :return: A column automapper type
+        """
+        return AutoMapperDataTypeField(value)
+
+    @staticmethod
+    def current() -> AutoMapperTextLikeBase:
+        """
+        Specifies to use the current item
+        :return: A column automapper type
+        """
+        return AutoMapperDataTypeField("_")
+
+    @staticmethod
+    def split_by_delimiter(
+        column: AutoMapperColumnOrColumnLikeType, delimiter: str
+    ) -> AutoMapperSplitByDelimiterDataType:
+        """
+        Split a string into an array using the delimiter
+
+        :param column: column whose contents to use
+        :param delimiter: string to use as delimiter
+        :return: a concat automapper type
+        """
+        return AutoMapperSplitByDelimiterDataType(
+            column=column, delimiter=delimiter
+        )
