@@ -5,6 +5,7 @@ from pyspark.sql.functions import array, expr
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.list import AutoMapperList
+from spark_auto_mapper.helpers.spark_higher_order_functions import filter
 
 
 def test_auto_mapper_array_single_item(spark_session: SparkSession) -> None:
@@ -36,8 +37,9 @@ def test_auto_mapper_array_single_item(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["dst2"]
-               ) == str(array(expr("address1")).alias("dst2"))
+    assert str(sql_expressions["dst2"]) == str(
+        filter(array(expr("address1")), lambda x: x.isNotNull()).alias("dst2")
+    )
 
     result_df: DataFrame = mapper.transform(df=df)
 
